@@ -10,7 +10,7 @@
 'use strict';
 
 var Utilities = {
-	VERSION	: "3.1",
+	VERSION	: "3.1.3",
 
 	exc : function() {
 		console.error.apply(console, arguments);
@@ -60,15 +60,18 @@ var Utilities = {
 		return uuid;
 	},
 
-	getSalt: function(l) {
-		if(l<32 || l>256) {
-			throw 'invalid salt length';
+	getSecureRandomString: function(len) {
+		const crypto = window.crypto || window.mscrypto;
+		if (!crypto) {
+			let s = "";
+			while (s.length<len) {
+				s += Utilities.getHexUUID();
+			}
+			return s.substr(0, len);
 		}
-		var s = '';
-		while (s.length<l) {
-			s += Utilities.getHexUUID();
-		}
-		return s.slice(0, l);
+		const u = new Uint8Array(len);
+		crypto.getRandomValues(u);
+		return String.fromCharCode.apply(null, u);
 	},
 
 	xorString: function(str1, str2){
@@ -176,7 +179,7 @@ var Utilities = {
 			}
 			//ie: "en"
 			layout = l[0].toLowerCase();
-			const tmp = LANGUAGE_TO_LAYOUT[v];
+			const tmp = LANGUAGE_TO_LAYOUT[layout];
 			if (tmp) {
 				layout = tmp;
 			}
