@@ -1,5 +1,5 @@
 /* This file is part of Xpra.
- * Copyright (C) 2012, 2013 Antoine Martin <antoine@devloop.org.uk>
+ * Copyright (C) 2012, 2013 Antoine Martin <antoine@xpra.org>
  * Xpra is released under the terms of the GNU GPL v2, or, at your option, any
  * later version. See the file COPYING for details.
  */
@@ -13,7 +13,7 @@
 #ifdef _WIN32
 #define _STDINT_H
 #endif
-#if !defined(__APPLE__) && !defined(__FreeBSD__) && !defined(__DragonFly__)
+#if !defined(__APPLE__) && !defined(__FreeBSD__) && !defined(__DragonFly__) && !defined(__OpenBSD__)
 #include <malloc.h>
 #endif
 
