@@ -12,7 +12,7 @@ from xpra.gtk_common.gobject_compat import import_gobject, import_gtk, import_gd
 from xpra.client.gtk_base.gtk_client_window_base import HAS_X11_BINDINGS, XSHAPE
 from xpra.gtk_common.quit import gtk_main_quit_really, gtk_main_quit_on_fatal_exceptions_enable
 from xpra.util import (
-    updict, pver, iround, flatten_dict, envbool, repr_ellipsized, csv, first_time,
+    updict, pver, iround, flatten_dict, envbool, repr_ellipsized, ellipsizer, csv, first_time,
     DEFAULT_METADATA_SUPPORTED, XPRA_OPENGL_NOTIFICATION_ID,
     )
 from xpra.os_util import (
@@ -802,7 +802,8 @@ class GTKXpraClient(GObjectXpraClient, UIXpraClient):
     def make_cursor(self, cursor_data):
         #if present, try cursor ny name:
         display = display_get_default()
-        cursorlog("make_cursor: has-name=%s, has-cursor-types=%s, xscale=%s, yscale=%s, USE_LOCAL_CURSORS=%s",
+        cursorlog("make_cursor(%s) has-name=%s, has-cursor-types=%s, xscale=%s, yscale=%s, USE_LOCAL_CURSORS=%s",
+                  ellipsizer(cursor_data),
                   len(cursor_data)>=10, bool(cursor_types), self.xscale, self.yscale, USE_LOCAL_CURSORS)
         #named cursors cannot be scaled
         #(round to 10 to compare so 0.95 and 1.05 are considered the same as 1.0, no scaling):
@@ -853,8 +854,8 @@ class GTKXpraClient(GObjectXpraClient, UIXpraClient):
                 img = Image.frombytes("RGBA", (w, h), pixels, "raw", "BGRA", w*4, 1)
                 target = Image.new("RGBA", (fw, fh))
                 target.paste(img, (0, 0, w, h))
-                pixels = img.tobytes("raw", "BGRA")
-                cursor_pixbuf = get_pixbuf_from_data(pixels, True, w, h, w*4)
+                pixels = target.tobytes("raw", "BGRA")
+                cursor_pixbuf = get_pixbuf_from_data(pixels, True, fw, fh, fw*4)
             else:
                 cursorlog("scaling cursor from %ix%i to fixed OS size %ix%i", w, h, fw, fh)
                 cursor_pixbuf = pixbuf.scale_simple(fw, fh, INTERP_BILINEAR)
