@@ -459,15 +459,18 @@ class WindowClient(StubClientMixin):
                 raise Exception("invalid cursor packet: %s items" % len(packet))
             #newer versions include the cursor encoding as first argument,
             #we know this is it because it will be a string rather than an int:
-            if isinstance(packet[0], (str, bytes)):
+            encoding = packet[0]
+            if isinstance(encoding, bytes):
+                encoding = encoding.decode("latin1")
+            if encoding in ("png", "raw"):
                 #we have the encoding in the packet already
                 new_cursor = packet
             else:
                 #prepend "raw" which is the default
-                new_cursor = [b"raw"] + packet
-            encoding = new_cursor[0]
+                new_cursor = ["raw"] + packet
+                encoding = "raw"
             pixels = new_cursor[8]
-            if encoding==b"png":
+            if encoding=="png":
                 if SAVE_CURSORS:
                     serial = new_cursor[7]
                     with open("raw-cursor-%#x.png" % serial, 'wb') as f:
@@ -476,8 +479,8 @@ class WindowClient(StubClientMixin):
                 img = open_only(pixels, ("png",))
                 new_cursor[8] = img.tobytes("raw", "BGRA")
                 cursorlog("used PIL to convert png cursor to raw")
-                new_cursor[0] = b"raw"
-            elif encoding!=b"raw":
+                new_cursor[0] = "raw"
+            elif encoding!="raw":
                 cursorlog.warn("Warning: invalid cursor encoding: %s", encoding)
                 return
         self.set_windows_cursor(self._id_to_window.values(), new_cursor)
@@ -1077,14 +1080,15 @@ class WindowClient(StubClientMixin):
 
     def _process_configure_override_redirect(self, packet):
         wid, x, y, w, h = packet[1:6]
-        window = self._id_to_window[wid]
+        window = self._id_to_window.get(wid)
         ax = self.sx(x)
         ay = self.sy(y)
         aw = max(1, self.sx(w))
         ah = max(1, self.sy(h))
         geomlog("_process_configure_override_redirect%s move resize window %s (id=%s) to %s",
                 packet[1:], window, wid, (ax,ay,aw,ah))
-        window.move_resize(ax, ay, aw, ah, -1)
+        if window:
+            window.move_resize(ax, ay, aw, ah, -1)
 
 
     def window_close_event(self, wid):
@@ -1410,6 +1414,8 @@ class WindowClient(StubClientMixin):
                 window.eos()
             return
         x, y, width, height, coding, data, packet_sequence, rowstride = packet[2:10]
+        for v in (x, y, width, height):
+            assert isinstance(v, int), "coordinates must be ints, found %s (%s)" % (v, type(v))
         if not window:
             #window is gone
             def draw_cleanup():
