@@ -331,7 +331,6 @@ class UIXpraClient(ClientBaseClass):
         body = "\n".join(info)
         self.may_notify(XPRA_DISCONNECT_NOTIFICATION_ID,
                         "Xpra Session Disconnected: %s" % reason, body, icon_name="disconnected")
-        self.exit_code = EXIT_OK
         delay = NOTIFICATION_EXIT_DELAY*mixin_features.notifications
         self.timeout_add(delay*1000, XpraClientBase.server_disconnect, self, reason, *info)
         self.cleanup()
@@ -558,8 +557,8 @@ class UIXpraClient(ClientBaseClass):
 
     def _process_control(self, packet):
         command = bytestostr(packet[1])
+        args = packet[2:]
         if command=="show_session_info":
-            args = packet[2:]
             log("calling show_session_info%s on server request", args)
             self.show_session_info(*args)
         elif command=="show_bug_report":
@@ -573,12 +572,11 @@ class UIXpraClient(ClientBaseClass):
             log.info("switching to %s on server request", pe)
             self._protocol.enable_encoder(pe)
         elif command=="name":
-            assert len(args)>=3
-            self.server_session_name = args[2]
+            assert len(args)>=1
+            self.server_session_name = bytestostr(args[0])
             log.info("session name updated from server: %s", self.server_session_name)
             #TODO: reset tray tooltip, session info title, etc..
         elif command=="debug":
-            args = packet[2:]
             if len(args)<2:
                 log.warn("not enough arguments for debug control command")
                 return
