@@ -1,6 +1,6 @@
 # This file is part of Xpra.
 # Copyright (C) 2008, 2009 Nathaniel Smith <njs@pobox.com>
-# Copyright (C) 2012-2018 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2012-2018 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -8,12 +8,15 @@ import os
 import sys
 import logging
 import weakref
+from collections import OrderedDict
 # This module is used by non-GUI programs and thus must not import gtk.
 
 from xpra.os_util import bytestostr
 
 LOG_PREFIX = bytestostr(os.environ.get("XPRA_LOG_PREFIX", ""))
 LOG_FORMAT = bytestostr(os.environ.get("XPRA_LOG_FORMAT", "%(asctime)s %(message)s"))
+
+DEBUG_MODULES = os.environ.get("XPRA_DEBUG_MODULES", "").split(",")
 NOPREFIX_FORMAT = u"%(message)s"
 
 logging.basicConfig(format=LOG_FORMAT)
@@ -35,20 +38,23 @@ def get_all_loggers():
     global all_loggers
     a = set()
     for loggers in all_loggers.values():
-        for l in list(loggers):
+        for logger in list(loggers):
             #weakref:
-            v = l()
-            if v:
-                a.add(v)
+            instance = logger()
+            if instance:
+                a.add(instance)
     return a
 
 
+debug_enabled_categories = set()
+debug_disabled_categories = set()
+
 class FullDebugContext(object):
 
     def __enter__(self):
         global debug_enabled_categories
         self.debug_enabled_categories = debug_enabled_categories
-        debug_enabled_categories = set(debug_enabled_categories)
+        debug_enabled_categories.clear()
         debug_enabled_categories.add("all")
         self.enabled = []
         for x in get_all_loggers():
@@ -60,11 +66,10 @@ class FullDebugContext(object):
         for x in self.enabled:
             x.disable_debug()
         global debug_enabled_categories
-        debug_enabled_categories = self.debug_enabled_categories
+        debug_enabled_categories.clear()
+        debug_enabled_categories.add(self.debug_enabled_categories)
 
 
-debug_enabled_categories = set()
-debug_disabled_categories = set()
 def add_debug_category(*cat):
     remove_disabled_category(*cat)
     for c in cat:
@@ -160,11 +165,10 @@ def enable_color(to=sys.stdout, format_string=NOPREFIX_FORMAT):
 def enable_format(format_string):
     try:
         logging.root.handlers[0].formatter = logging.Formatter(format_string)
-    except:
+    except (AttributeError, IndexError):
         pass
 
 
-from collections import OrderedDict
 STRUCT_KNOWN_FILTERS = OrderedDict([
     ("Client", OrderedDict([
                 ("client"       , "All client code"),
@@ -198,6 +202,7 @@ STRUCT_KNOWN_FILTERS = OrderedDict([
                 ("focus"        , "Window focus"),
                 ("workspace"    , "Window workspace synchronization"),
                 ("metadata"     , "Window metadata"),
+                ("alpha"        , "Window Alpha channel (transparency)"),
                 ("state"        , "Window state"),
                 ("icon"         , "Window icons"),
                 ("frame"        , "Window frame"),
@@ -236,6 +241,7 @@ STRUCT_KNOWN_FILTERS = OrderedDict([
                 ("pillow"       , "Pillow encoder and decoder"),
                 ("jpeg"         , "JPEG codec"),
                 ("vpx"          , "libvpx encoder and decoder"),
+                ("nvjpeg"       , "nvidia nvjpeg hardware encoder"),
                 ("nvenc"        , "nvenc hardware encoder"),
                 ("nvfbc"        , "nfbc screen capture"),
                 ("x264"         , "libx264 encoder"),
@@ -312,7 +318,7 @@ STRUCT_KNOWN_FILTERS = OrderedDict([
 
 #flatten it:
 KNOWN_FILTERS = OrderedDict()
-for category, d in STRUCT_KNOWN_FILTERS.items():
+for d in STRUCT_KNOWN_FILTERS.values():
     for k,v in d.items():
         KNOWN_FILTERS[k] = v
 
@@ -340,18 +346,24 @@ class Logger(object):
     def __init__(self, *categories):
         global default_level, debug_disabled_categories, KNOWN_FILTERS
         self.categories = list(categories)
-        caller = sys._getframe(1).f_globals["__name__"]
-        if caller!="__main__":
+        try:
+            caller = sys._getframe(1).f_globals["__name__"] #pylint: disable=protected-access
+        except AttributeError:
+            caller = None
+        if caller not in ("__main__", None):
             self.categories.insert(0, caller)
         self.logger = logging.getLogger(".".join(self.categories))
         self.logger.setLevel(default_level)
         disabled = False
         enabled = False
-        for cat in self.categories:
-            if cat in debug_disabled_categories:
-                disabled = True
-            if is_debug_enabled(cat):
-                enabled = True
+        if caller in DEBUG_MODULES:
+            enabled = True
+        else:
+            for cat in self.categories:
+                if cat in debug_disabled_categories:
+                    disabled = True
+                if is_debug_enabled(cat):
+                    enabled = True
         self.debug_enabled = enabled and not disabled
         #ready, keep track of it:
         add_logger(self.categories, self)
@@ -417,3 +429,61 @@ class CaptureHandler(logging.Handler):
 
     def createLock(self):
         self.lock = None
+
+class SIGPIPEStreamHandler3(logging.StreamHandler):
+
+    def flush(self):
+        try:
+            super().flush()
+        except BrokenPipeError:
+            pass
+
+    def emit(self, record):
+        try:
+            msg = self.format(record)
+            stream = self.stream
+            # issue 35046: merged two stream.writes into one.
+            stream.write(msg + self.terminator)
+            self.flush()
+        except RecursionError:  # See issue 36272
+            raise
+        except BrokenPipeError:
+            pass
+        except Exception:
+            self.handleError(record)
+
+class SIGPIPEStreamHandler2(logging.StreamHandler):
+
+    def flush(self):
+        try:
+            logging.StreamHandler.flush(self)
+        except IOError:
+            pass
+
+    def emit2(self, record):
+        try:
+            msg = self.format(record)
+            stream = self.stream
+            fs = "%s\n"
+            try:
+                if (isinstance(msg, unicode) and
+                    getattr(stream, 'encoding', None)):
+                    ufs = u'%s\n'
+                    try:
+                        stream.write(ufs % msg)
+                    except UnicodeEncodeError:
+                        stream.write((ufs % msg).encode(stream.encoding))
+                else:
+                    stream.write(fs % msg)
+            except UnicodeError:
+                stream.write(fs % msg.encode("UTF-8"))
+            self.flush()
+        except RuntimeError:  # See issue 36272
+            pass
+        except Exception:
+            self.handleError(record)
+
+if sys.version_info[0]==2:
+   SIGPIPEStreamHandler = SIGPIPEStreamHandler2
+else:
+   SIGPIPEStreamHandler = SIGPIPEStreamHandler3
