@@ -31,12 +31,10 @@ def get_socket_group(socket_filename):
 def xpra_group():
     if POSIX:
         try:
-            username = os.getgroups()
-            groups = get_groups(username)
-            if MMAP_GROUP in groups:
-                group_id = get_group_id(MMAP_GROUP)
-                if group_id>=0:
-                    return group_id
+            groups = os.getgroups()
+            group_id = get_group_id(MMAP_GROUP)
+            if group_id and group_id in groups:
+                return group_id
         except Exception:
             log("xpra_group()", exc_info=True)
     return 0
@@ -72,7 +70,6 @@ def init_client_mmap(mmap_group=None, socket_filename=None, size=128*1024*1024,
             mmap_area = mmap.mmap(0, mmap_size, filename)
             #not a real file:
             delete = False
-            mmap_temp_file = None
         else:
             assert POSIX
             if filename:
@@ -160,7 +157,15 @@ def init_client_mmap(mmap_group=None, socket_filename=None, size=128*1024*1024,
         log("failed to setup mmap: %s", e, exc_info=True)
         log.error("Error: mmap setup failed:")
         log.error(" %s", e)
-        clean_mmap(mmap_filename)
+        if delete:
+            if mmap_temp_file:
+                try:
+                    mmap_temp_file.close()
+                except OSError:
+                    log("%s()", mmap_temp_file.close, exc_info=True)
+                    log.error(" failed to remove the mmap temp file: %s", e)
+            else:
+                clean_mmap(mmap_filename)
         return rerr()
 
 def clean_mmap(mmap_filename):
