@@ -333,6 +333,15 @@ def is_Arch():
 def is_CentOS():
     return is_distribution_variant(b"CentOS")
 
+def is_AlmaLinux():
+    return is_distribution_variant(b"AlmaLinux")
+
+def is_RockyLinux():
+    return is_distribution_variant(b"Rocky Linux")
+
+def is_OracleLinux():
+    return is_distribution_variant(b"Oracle Linux")
+
 def is_RedHat():
     return is_distribution_variant(b"RedHat")
 
@@ -741,7 +750,7 @@ def find_lib_ldconfig(libname):
             ldconfig = t
             break
     import subprocess
-    p = subprocess.Popen([ldconfig, "-p"], stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
+    p = subprocess.Popen("%s -p" % ldconfig, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
     data = bytestostr(p.communicate()[0])
 
     libpath = re.search(pattern, data, re.MULTILINE)        #@UndefinedVariable
@@ -755,8 +764,10 @@ def find_lib(libname):
     #it found the library in
     assert POSIX
     libpaths = os.environ.get("LD_LIBRARY_PATH", "").split(":")
-    libpaths.append("/usr/lib64")
-    libpaths.append("/usr/lib")
+    if BITS==64 and os.path.exists("/usr/lib64"):
+        libpaths.append("/usr/lib64")
+    else:
+        libpaths.append("/usr/lib")
     for libpath in libpaths:
         if not libpath or not os.path.exists(libpath):
             continue
@@ -776,12 +787,24 @@ def pollwait(process, timeout=5):
     return None
 
 def which(command):
-    from distutils.spawn import find_executable
     try:
-        return find_executable(command)
-    except Exception:
-        get_util_logger().debug("find_executable(%s)", command, exc_info=True)
+        from distutils.spawn import find_executable
+    except ImportError:
+        path = os.environ.get("PATH", None)
+        if not path:
+            return None
+        paths = path.split(os.pathsep)
+        for p in paths:
+            f = os.path.join(p, command)
+            if os.path.isfile(f):
+                return f
         return None
+    else:
+        try:
+            return find_executable(command)
+        except Exception:
+            get_util_logger().debug("find_executable(%s)", command, exc_info=True)
+            return None
 
 def get_status_output(*args, **kwargs):
     import subprocess
