@@ -377,7 +377,7 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
     clobber   = int(upgrading or upgrading_desktop) | int(opts.use_display)*2
     start_vfb = not (shadowing or proxying or clobber)
 
-    if not proxying and PYTHON3 and POSIX and not OSX:
+    if not proxying and POSIX and not OSX:
         #we don't support wayland servers,
         #so make sure GDK will use the X11 backend:
         from xpra.os_util import saved_env
@@ -392,7 +392,8 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
             )
     if proxying or upgrading or upgrading_desktop:
         #when proxying or upgrading, don't exec any plain start commands:
-        opts.start = opts.start_child = []
+        opts.start = []
+        opts.start_child = []
     elif opts.exit_with_children:
         assert has_child_arg, "exit-with-children was specified but start-child* is missing!"
     elif opts.start_child:
@@ -826,13 +827,13 @@ def do_run_server(error_cb, opts, mode, xpra_file, extra_args, desktop_display=N
         #all unix domain sockets:
         ud_paths = [sockpath for stype, _, sockpath, _ in local_sockets if stype=="unix-domain"]
         if ud_paths:
+            os.environ["XPRA_SERVER_SOCKET"] = ud_paths[0]
             #choose one so our xdg-open override script can use to talk back to us:
             if opts.forward_xdg_open:
                 for x in ("/usr/libexec/xpra", "/usr/lib/xpra"):
                     xdg_override = os.path.join(x, "xdg-open")
                     if os.path.exists(xdg_override):
                         os.environ["PATH"] = x+os.pathsep+os.environ.get("PATH", "")
-                        os.environ["XPRA_SERVER_SOCKET"] = ud_paths[0]
                         break
         else:
             log.warn("Warning: no local server sockets,")
