@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # This file is part of Xpra.
-# Copyright (C) 2013, 2014 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2013, 2014 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -32,16 +32,17 @@ class Worker_Thread(Thread):
     def stop(self, force=False):
         if self.exit:
             return
+        items = tuple(x for x in tuple(self.items.queue) if x is not None)
+        log("Worker_Thread.stop(%s) %i items still in work queue: %s", force, len(items), items)
         if force:
-            if self.items.qsize()>0:
-                log.warn("Worker stop: %s items in the queue will not be run!", self.items.qsize())
+            if items:
+                log.warn("Worker stop: %s items in the queue will not be run!", len(items))
                 self.items.put(None)
                 self.items = Queue()
             self.exit = True
         else:
-            if self.items.qsize()>0:
-                log.info("waiting for %s items in work queue to complete", self.items.qsize())
-        debug("Worker_Thread.stop(%s) %s items in work queue", force, self.items)
+            if items:
+                log.info("waiting for %s items in work queue to complete", len(items))
         self.items.put(None)
 
     def add(self, item):
@@ -60,7 +61,7 @@ class Worker_Thread(Thread):
             try:
                 debug("Worker_Thread.run() calling %s (queue size=%s)", item, self.items.qsize())
                 item()
-            except:
+            except Exception:
                 log.error("Error in worker thread processing item %s", item, exc_info=True)
         debug("Worker_Thread.run() ended (queue size=%s)", self.items.qsize())
 
