@@ -7,7 +7,7 @@
 
 import os.path
 
-from xpra.os_util import OSX, POSIX
+from xpra.os_util import OSX, POSIX, bytestostr
 from xpra.util import engs
 from xpra.scripts.config import FALSE_OPTIONS
 from xpra.server.mixins.stub_server_mixin import StubServerMixin
@@ -133,7 +133,7 @@ class WebcamServer(StubServerMixin):
             log.warn("Warning: invalid client source for webcam frame")
             return
         device_id, frame_no, encoding, w, h, data = packet[1:7]
-        ss.process_webcam_frame(device_id, frame_no, encoding, w, h, data)
+        ss.process_webcam_frame(device_id, frame_no, bytestostr(encoding), w, h, data)
 
     def init_packet_handlers(self):
         if self.webcam_enabled:
