@@ -491,6 +491,11 @@ class ProxyInstance(object):
             self.encode_queue.put(packet)
             #which will queue the packet itself when done:
             return
+        elif packet_type=="sound-data":
+            sound_data = packet[2]
+            if sound_data:
+                #best if we use raw packets for the actual sound-data chunk:
+                packet[2] = Compressed("sound-data", sound_data)
         #we do want to reformat cursor packets...
         #as they will have been uncompressed by the network layer already:
         elif packet_type=="cursor":
@@ -569,6 +574,15 @@ class ProxyInstance(object):
 
     def encode_loop(self):
         """ thread for slower encoding related work """
+        def delvideo(wid):
+            try:
+                del self.video_encoders[wid]
+            except KeyError:
+                pass
+            try:
+                del self.video_encoders_last_used_time[wid]
+            except KeyError:
+                pass
         while not self.exit:
             packet = self.encode_queue.get()
             if packet is None:
@@ -580,8 +594,7 @@ class ProxyInstance(object):
                     self.lost_windows.remove(wid)
                     ve = self.video_encoders.get(wid)
                     if ve:
-                        del self.video_encoders[wid]
-                        del self.video_encoders_last_used_time[wid]
+                        delvideo(wid)
                         ve.clean()
                 elif packet_type==b"draw":
                     #modify the packet with the video encoder:
@@ -593,14 +606,13 @@ class ProxyInstance(object):
                     wid = packet[1]
                     ve = self.video_encoders.get(wid)
                     now = monotonic_time()
-                    idle_time = now-self.video_encoders_last_used_time.get(wid)
+                    idle_time = now-self.video_encoders_last_used_time.get(wid, 0)
                     if ve and idle_time>VIDEO_TIMEOUT:
                         enclog("timing out the video encoder context for window %s", wid)
                         #timeout is confirmed, we are in the encoding thread,
                         #so it is now safe to clean it up:
                         ve.clean()
-                        del self.video_encoders[wid]
-                        del self.video_encoders_last_used_time[wid]
+                        delvideo(wid)
                 else:
                     enclog.warn("unexpected encode packet: %s", packet_type)
             except Exception:
@@ -609,10 +621,15 @@ class ProxyInstance(object):
 
     def process_draw(self, packet):
         wid, x, y, width, height, encoding, pixels, _, rowstride, client_options = packet[1:11]
+        encoding = bytestostr(encoding)
         #never modify mmap packets
-        if encoding in (b"mmap", b"scroll"):
+        if encoding in ("mmap", "scroll"):
+            return True
+        #we can only use video encoders on RGB data:
+        if encoding not in ("rgb24", "rgb32", "r210", "BGR565"):
+            #this prevents compression and inlining of pixel data:
+            packet[7] = Compressed("%s pixels" % encoding, pixels)
             return True
-
         client_options = typedict(client_options)
         #we have a proxy video packet:
         rgb_format = client_options.strget("rgb_format", "")
@@ -648,10 +665,10 @@ class ProxyInstance(object):
                 new_client_options = client_options
             wrapped = Compressed("%s pixels" % encoding, cdata)
             #rgb32 is always supported by all clients:
-            return send_updated("rgb32", wrapped, new_client_options)
+            return send_updated(encoding, wrapped, new_client_options)
 
         proxy_video = client_options.boolget("proxy", False)
-        if PASSTHROUGH_RGB and (encoding in ("rgb32", "rgb24") or proxy_video):
+        if PASSTHROUGH_RGB:
             #we are dealing with rgb data, so we can pass it through:
             return passthrough(proxy_video)
         if not self.video_encoder_types or not client_options or not proxy_video:
@@ -740,9 +757,10 @@ class ProxyInstance(object):
         #to do what may need to be done if we find a timeout:
         now = monotonic_time()
         for wid in tuple(self.video_encoders_last_used_time.keys()):
-            idle_time = int(now-self.video_encoders_last_used_time.get(wid))
-            if idle_time is None:
+            vetime = self.video_encoders_last_used_time.get(wid)
+            if not vetime:
                 continue
+            idle_time = int(now-vetime)
             enclog("timeout_video_encoders() wid=%s, idle_time=%s", wid, idle_time)
             if idle_time and idle_time>VIDEO_TIMEOUT:
                 self.encode_queue.put(["check-video-timeout", wid])
