@@ -225,6 +225,7 @@ class ServerCore(object):
         self._socket_timeout = SERVER_SOCKET_TIMEOUT
         self._ws_timeout = 5
         self._socket_dir = None
+        self._socket_dirs = []
         self.dbus_pid = 0
         self.dbus_env = {}
         self.dbus_control = False
@@ -282,6 +283,7 @@ class ServerCore(object):
         self._socket_dir = opts.socket_dir or ""
         if not self._socket_dir and opts.socket_dirs:
             self._socket_dir = opts.socket_dirs[0]
+        self._socket_dirs = opts.socket_dirs
         self.encryption = opts.encryption
         self.encryption_keyfile = opts.encryption_keyfile
         self.tcp_encryption = opts.tcp_encryption
@@ -490,12 +492,15 @@ class ServerCore(object):
         dbuslog("stop_dbus_server() dbus_pid=%s", self.dbus_pid)
         if not self.dbus_pid:
             return
-        try:
-            os.kill(self.dbus_pid, signal.SIGINT)
-        except Exception as e:
-            dbuslog("os.kill(%i, SIGINT)", self.dbus_pid, exc_info=True)
-            dbuslog.warn("Warning: error trying to stop dbus with pid %i:", self.dbus_pid)
-            dbuslog.warn(" %s", e)
+        from xpra.scripts.server import add_cleanup
+        def do_kill_dbus():
+            try:
+                os.kill(self.dbus_pid, signal.SIGINT)
+            except Exception as e:
+                dbuslog("os.kill(%i, SIGINT)", self.dbus_pid, exc_info=True)
+                dbuslog.warn("Warning: error trying to stop dbus with pid %i:", self.dbus_pid)
+                dbuslog.warn(" %s", e)
+        add_cleanup(do_kill_dbus)
 
     def init_dbus_server(self):
         if not POSIX:
@@ -577,11 +582,15 @@ class ServerCore(object):
         if www_dir:
             self._www_dir = www_dir
         else:
-            for ad,d in (
+            dirs = [
                 (get_resources_dir(), "html5"),
                 (get_resources_dir(), "www"),
                 (get_app_dir(), "www"),
-                ):
+                ]
+            if POSIX:
+                for d in ("/usr/share/xpra", "/usr/local/share/xpra"):
+                    dirs.append((d, "www"))
+            for ad,d in dirs:
                 self._www_dir = os.path.abspath(os.path.join(ad, d))
                 if os.path.exists(self._www_dir):
                     httplog("found html5 client in '%s'", self._www_dir)
@@ -1412,14 +1421,19 @@ class ServerCore(object):
         return self.send_http_response(handler, "ready")
 
     def send_http_response(self, handler, content, content_type="text/plain"):
-        handler.send_response(200)
-        headers = {
-            "Content-type"      : content_type,
-            "Content-Length"    : len(content),
-            }
-        for k,v in headers.items():
-            handler.send_header(k, v)
+        if content is None:
+            handler.send_response(404)
+        else:
+            handler.send_response(200)
+            headers = {
+                "Content-type"      : content_type,
+                "Content-Length"    : len(content),
+                }
+            for k,v in headers.items():
+                handler.send_header(k, v)
         handler.end_headers()
+        if isinstance(content, str):
+            content = content.encode("latin1")
         return content
 
 
@@ -1635,6 +1649,11 @@ class ServerCore(object):
                 auth, aclass, options = auth_class
                 opts = dict(options)
                 opts["connection"] = conn
+                def parse_socket_dirs(v):
+                    if isinstance(v, (tuple, list)):
+                        return v
+                    return str(v).split(",")
+                opts["socket-dirs"] = parse_socket_dirs(opts.get("socket-dirs", self._socket_dirs))
                 authenticator = aclass(username, **opts)
                 authlog("authenticator %i: %s(%s, %s)=%s", i, auth, username, opts, authenticator)
                 authenticators.append(authenticator)
@@ -1847,13 +1866,13 @@ class ServerCore(object):
         if is_req("id"):
             self.send_id_info(proto)
             return True
+        if self._closing:
+            self.disconnect_client(proto, SERVER_EXIT, "server is shutting down")
+            return True
         if is_req("info"):
             flatten = not c.boolget("info-namespace", False)
             self.send_hello_info(proto, flatten)
             return True
-        if self._closing:
-            self.disconnect_client(proto, SERVER_EXIT, "server is shutting down")
-            return True
         return False
 
 
