@@ -16,9 +16,13 @@ def source_env(source=()):
     log = get_util_logger()
     env = {}
     for f in source:
-        e = env_from_sourcing(f)
-        log("source_env %s=%s", f, e)
-        env.update(e)
+        try:
+            e = env_from_sourcing(f)
+        except Exception:
+            log.error("Error sourcing %r", f, exc_info=True)
+        else:
+            log("source_env %s=%s", f, e)
+            env.update(e)
     return env
 
 
@@ -58,8 +62,8 @@ def env_from_sourcing(file_to_source_path, include_unexported_variables=False):
             return env
     else:
         source = '%ssource %s' % ("set -a && " if include_unexported_variables else "", filename)
-        dump = '/usr/bin/python -c "import os, json;print(json.dumps(dict(os.environ)))"'
-        cmd = ['/bin/bash', '-c', '%s && %s' % (source, dump)]
+        dump = 'python%i.%i -c "import os, json;print(json.dumps(dict(os.environ)))"' % (sys.version_info.major, sys.version_info.minor)
+        cmd = ['/bin/bash', '-c', '%s 1>&2 && %s' % (source, dump)]
         def decode(out):
             try:
                 env = json.loads(out)
