@@ -323,9 +323,11 @@ class WindowModel(BaseWindowModel):
         set_if_unset("requested-position", (ax, ay))
         set_if_unset("requested-size", (aw, ah))
         #it may have been set already:
-        v = self.get_property("set-initial-position")
-        if not v and ("position" in size_hints):
+        sip = self.get_property("set-initial-position")
+        if not sip and ("position" in size_hints):
             self._internal_set_property("set-initial-position", True)
+        elif sip is None:
+            self._internal_set_property("set-initial-position", False)
         self.update_children()
 
     def do_unmanaged(self, wm_exiting):
@@ -620,7 +622,7 @@ class WindowModel(BaseWindowModel):
         # As per ICCCM 4.1.5, even if we ignore the request
         # send back a synthetic ConfigureNotify telling the client that nothing has happened.
         with xswallow:
-            X11Window.configureAndNotify(self.xid, x, y, w, h)
+            X11Window.configureAndNotify(self.xid, x, y, w, h, event.value_mask)
         # FIXME: consider handling attempts to change stacking order here.
         # (In particular, I believe that a request to jump to the top is
         # meaningful and should perhaps even be respected.)
@@ -665,7 +667,8 @@ class WindowModel(BaseWindowModel):
             geomlog("update_size_constraints%s less restrictive, no need to recalculate", (minw, minh, maxw, maxh))
             return
         geomlog("update_size_constraints%s recalculating client geometry", (minw, minh, maxw, maxh))
-        self._update_client_geometry()
+        if self._setup_done and self.get_property("owner"):
+            self._update_client_geometry()
 
     #########################################
     # X11 properties synced to Python objects
@@ -740,7 +743,7 @@ class WindowModel(BaseWindowModel):
         if 0<cmaxh<hmaxh:
             hmaxh = cmaxh
         #if the values mean something, expose them:
-        if hminw>0 or hminw>0:
+        if hminw>0 or hminh>0:
             hints["minimum-size"] = hminw, hminh
         if hmaxw<MAX_WINDOW_SIZE or hmaxh<MAX_WINDOW_SIZE:
             hints["maximum-size"] = hmaxw, hmaxh
@@ -757,7 +760,7 @@ class WindowModel(BaseWindowModel):
         # reduces the chance for us to get caught in loops:
         if self._updateprop("size-hints", hints):
             metalog("updated: size-hints=%s", hints)
-            if self._setup_done:
+            if self._setup_done and self.get_property("owner"):
                 self._update_client_geometry()
 
 
